@@ -5,6 +5,10 @@ from redbot.core import commands
 from pylav.utils import PyLavContext
 
 
+class IncompatibleException(EnvironmentError):
+    """Command raised when an incompatible cog is already loaded."""
+
+
 class MediaPlayerError(commands.CommandError):
     """
     Base class for all media player errors.
@@ -33,3 +37,12 @@ class MediaPlayerNotFoundError(MediaPlayerCheckError, commands.CheckFailure):
 
     def __init__(self, context: PyLavContext) -> None:
         self.context = context
+
+
+class NotDJError(MediaPlayerCheckError, commands.CheckFailure):
+    """
+    Raised when user does not have DJ Perms.
+    """
+
+    def __init__(self, context: PyLavContext) -> None:
+        self.context = context
