@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import contextlib
 from pathlib import Path
 from typing import Literal
 
@@ -45,32 +46,14 @@ class DisconnectButton(discord.ui.Button):
                 ephemeral=True,
             )
             return
-        self.view.bot.dispatch("red_audio_audio_disconnect", player.guild)
-        self.cog.update_player_lock(player, False)
-        player.queue = []
-        player.store("playing_song", None)
-        player.store("autoplay_notified", False)
-        channel_id = player.fetch("notify_channel")
-        notify_channel = player.guild.get_channel_or_thread(channel_id)
-        if player.equalizer.changed:
-            async with self.cog.config.custom("EQUALIZER", player.guild.id).all() as eq_data:
-                eq_data["eq_bands"] = player.equalizer.get()
-                eq_data["name"] = player.equalizer.name
-        await player.stop()
-        await player.disconnect()
-        if notify_channel:
-            # TODO Use Text input to get a message from owner to send
-            await self.cog.send_embed_msg(
-                notify_channel, title=_("Bot Owner Action"), description=_("Player disconnected.")
-            )
-        self.cog._ll_guild_updates.discard(player.guild.id)  # noqa
-        await self.cog.api_interface.persistent_queue_api.drop(player.guild.id)
-        await self.cog.clean_up_guild_config(
-            "last_known_vc_and_notify_channels",
-            "last_known_track",
-            "currently_auto_playing_in",
-            guild_ids=[player.guild.id],
-        )
+        if notify_channel := player.notify_channel:
+            with contextlib.suppress(discord.HTTPException):
+                await notify_channel.send(
+                    embed=await self.cog.lavalink.construct_embed(
+                        title=_("Bot Owner Action"), description=_("Player disconnected")
+                    )
+                )
+        await player.disconnect(requester=interaction.user)
 
         await self.view.prepare()
         kwargs = await self.view.get_page(self.view.current_page)
@@ -109,28 +92,16 @@ class StopTrackButton(discord.ui.Button):
                 ephemeral=True,
             )
             return
-        if player.equalizer.changed:
-            async with self.cog.config.custom("EQUALIZER", player.guild.id).all() as eq_data:
-                eq_data["eq_bands"] = player.equalizer.get()
-                eq_data["name"] = player.equalizer.name
-        player.queue = []
-        player.store("playing_song", None)
-        player.store("prev_requester", None)
-        player.store("prev_song", None)
-        player.store("requester", None)
-        player.store("autoplay_notified", False)
+
         await player.stop()
-        channel_id = player.fetch("notify_channel")
-        if notify_channel := player.guild.get_channel_or_thread(channel_id):
-            # TODO Use Text input to get a message from owner to send?
-            await self.cog.send_embed_msg(notify_channel, title=_("Bot Owner Action"), description=_("Player stopped."))
-        await self.cog.api_interface.persistent_queue_api.drop(player.guild.id)
-        await self.cog.clean_up_guild_config(
-            "last_known_vc_and_notify_channels",
-            "last_known_track",
-            "currently_auto_playing_in",
-            guild_ids=[player.guild.id],
-        )
+        if notify_channel := player.notify_channel:
+            with contextlib.suppress(discord.HTTPException):
+                await notify_channel.send(
+                    embed=await self.cog.lavalink.construct_embed(
+                        title=_("Bot Owner Action"), description=_("Player stopped.")
+                    )
+                )
+
         await self.view.prepare()
         kwargs = await self.view.get_page(self.view.current_page)
         await (await interaction.original_message()).edit(view=self.view, **kwargs)
@@ -177,32 +148,15 @@ class DisconnectAllButton(discord.ui.Button):
             )
             return
         async for player in AsyncIter(players):
-            self.view.bot.dispatch("red_audio_audio_disconnect", player.guild)
-            self.cog.update_player_lock(player, False)
-            player.queue = []
-            channel_id = player.fetch("notify_channel")
-            notify_channel = player.guild.get_channel_or_thread(channel_id)
-            if player.equalizer.changed:
-                async with self.cog.config.custom("EQUALIZER", player.guild.id).all() as eq_data:
-                    eq_data["eq_bands"] = player.equalizer.get()
-                    eq_data["name"] = player.equalizer.name
-            await player.stop(requester=interaction.user)
+            if notify_channel := player.notify_channel:
+                with contextlib.suppress(discord.HTTPException):
+                    await notify_channel.send(
+                        embed=await self.cog.lavalink.construct_embed(
+                            title=_("Bot Owner Action"), description=_("Player disconnected")
+                        )
+                    )
             await player.disconnect(requester=interaction.user)
-            if notify_channel:
-                # TODO Use Text input to get a message from owner to send
-                await self.cog.send_embed_msg(
-                    notify_channel,
-                    title=_("Bot Owner Action"),
-                    description=_("Player disconnected."),
-                )
-            self.cog._ll_guild_updates.discard(player.guild.id)  # noqa
-            await self.cog.api_interface.persistent_queue_api.drop(player.guild.id)
-            await self.cog.clean_up_guild_config(
-                "last_known_vc_and_notify_channels",
-                "last_known_track",
-                "currently_auto_playing_in",
-                guild_ids=[player.guild.id],
-            )
+
         await self.view.prepare()
         kwargs = await self.view.get_page(self.view.current_page)
         await (await interaction.original_message()).edit(view=self.view, **kwargs)
