@@ -7,23 +7,36 @@ import threading
 from pathlib import Path
 from types import MethodType
 
+import asyncstdlib
 import discord
 from red_commons.logging import getLogger
 from redbot.core import commands
 from redbot.core.data_manager import cog_data_path
 from redbot.core.i18n import Translator
+from redbot.core.utils.chat_formatting import box
+from tabulate import tabulate
 
 from pylav import Client, NoNodeAvailable
 from pylav.exceptions import NoNodeWithRequestFunctionalityAvailable
 from pylav.types import BotT, CogT
 from pylav.utils import PyLavContext
 
-from pylavcogs_shared.errors import MediaPlayerNotFoundError, UnauthorizedChannelError
+from pylavcogs_shared import __VERSION__ as pylavcogs_shared_version
+from pylavcogs_shared.errors import (
+    IncompatibleException,
+    MediaPlayerNotFoundError,
+    NotDJError,
+    UnauthorizedChannelError,
+)
 
 _ = Translator("PyLavShared", Path(__file__))
 _LOCK = threading.Lock()
 LOGGER = getLogger("red.3pt.PyLav-Shared.utils.overrides")
 
+INCOMPATIBLE_COGS = {
+    "ReactToCommand",
+}
+
 
 @commands.command(
     cls=commands.commands._AlwaysAvailableCommand,
@@ -55,6 +68,32 @@ async def pylav_credits(context: PyLavContext) -> None:
     )
 
 
+@commands.command(
+    cls=commands.commands._AlwaysAvailableCommand,
+    name="plversion",
+    aliases=["pylavversion"],
+    i18n=_,
+)
+async def pylav_version(context: PyLavContext) -> None:
+    """Show the version of PyLav and PyLavCogs-Shared libraries."""
+    if isinstance(context, discord.Interaction):
+        context = await context.client.get_context(context)
+    if context.interaction and not context.interaction.response.is_done():
+        await context.defer(ephemeral=True)
+    data = [
+        ("PyLavCogs-Shared", pylavcogs_shared_version),
+        ("PyLav", context.lavalink.lib_version),
+    ]
+
+    await context.send(
+        embed=await context.lavalink.construct_embed(
+            description=box(tabulate(data, headers=(_("Library"), _("Version")), tablefmt="fancy_grid")),
+            messageable=context,
+        ),
+        ephemeral=True,
+    )
+
+
 def _done_callback(task: asyncio.Task) -> None:
     with contextlib.suppress(asyncio.CancelledError):
         exc = task.exception()
@@ -112,6 +151,16 @@ async def cog_command_error(self: CogT, context: PyLavContext, error: Exception)
             ephemeral=True,
             delete_after=10,
         )
+    elif isinstance(error, NotDJError):
+        unhandled = False
+        await context.send(
+            embed=await self.lavalink.construct_embed(
+                messageable=context,
+                description=_("This command requires you to be a DJ."),
+            ),
+            ephemeral=True,
+            delete_after=10,
+        )
     if unhandled:
         if (meth := getattr(self, "__pylav_original_cog_command_error", None)) and (
             func := self._get_overridden_method(meth)
@@ -128,10 +177,27 @@ async def cog_unload(self: CogT) -> None:
     await client.unregister(cog=self)
     if client._shutting_down:
         self.bot.remove_command(pylav_credits.qualified_name)
+        self.bot.remove_command(pylav_version.qualified_name)
     if meth := getattr(self, "__pylav_original_cog_unload", None):
         return await discord.utils.maybe_coroutine(meth)
 
 
+async def cog_before_invoke(self: CogT, context: PyLavContext):
+    try:
+        await self.lavalink.wait_until_ready(timeout=30)
+    except asyncio.TimeoutError:
+        LOGGER.debug("Discarded command due to PyLav not being ready within 30 seconds")
+        LOGGER.verbose(
+            "Discarded command due to PyLav not being ready within 30 seconds - Guild: %s - Command: %s",
+            context.guild,
+            context.command.qualified_name,
+        )
+
+        raise discord.ext.commands.CheckFailure(_("PyLav is not ready - Please try again shortly."))
+    if meth := getattr(self, "__pylav_original_cog_before_invoke", None):
+        return await discord.utils.maybe_coroutine(meth)
+
+
 async def initialize(self: CogT, *args, **kwargs) -> None:
     if not self.init_called:
         await self.lavalink.register(self)
@@ -141,17 +207,25 @@ async def initialize(self: CogT, *args, **kwargs) -> None:
         return await discord.utils.maybe_coroutine(meth, *args, **kwargs)
 
 
-async def cog_check(self: CogT, ctx: PyLavContext) -> bool:
+async def cog_check(self: CogT, context: PyLavContext) -> bool:
+
+    # This cog mock discord objects and sends them on the listener
+    #   Due to the potential risk for unexpected behaviour - disabled all commands if this cog is loaded.
+    if await asyncstdlib.any(context.bot.get_cog(name) is not None for name in INCOMPATIBLE_COGS):
+        return False
+    if not (getattr(context.bot, "lavalink", None)):
+        return False
     meth = getattr(self, "__pylav_original_cog_check", None)
-    if not ctx.guild:
-        return await discord.utils.maybe_coroutine(meth, ctx) if meth else True
-    if ctx.player:
-        config = ctx.player.config
+    if not context.guild:
+        return await discord.utils.maybe_coroutine(meth, context) if meth else True
+    if getattr(context, "player", None):
+        config = context.player.config
+        await config.update()
     else:
-        config = await self.lavalink.player_config_manager.get_config(ctx.guild.id)
-    if config.text_channel_id and config.text_channel_id != ctx.channel.id:
-        raise UnauthorizedChannelError(channel=config.text_channel_id)
-    return await discord.utils.maybe_coroutine(meth, ctx) if meth else True
+        config = await context.bot.lavalink.player_config_manager.get_config(context.guild.id)
+    if config.text_channel_id and config.text_channel_id != context.channel.id:
+        return False
+    return await discord.utils.maybe_coroutine(meth, context) if meth else True
 
 
 def class_factory(
@@ -164,16 +238,21 @@ def class_factory(
     Creates a new class which inherits from the given class and overrides the following methods:
     - cog_check
     - cog_unload
+    - cog_before_invoke
     - initialize
     - cog_command_error
     """
     if not bot.get_command(pylav_credits.qualified_name):
         bot.add_command(pylav_credits)
+    if not bot.get_command(pylav_version.qualified_name):
+        bot.add_command(pylav_version)
     argspec = inspect.getfullargspec(cls.__init__)
     if ("bot" in argspec.args or "bot" in argspec.kwonlyargs) and bot not in cogargs:
         cogkwargs["bot"] = bot
 
     cog_instance = cls(*cogargs, **cogkwargs)
+    if not hasattr(cog_instance, "__version__"):
+        cog_instance.__version__ = "0.0.0"
     cog_instance.lavalink = Client(bot=bot, cog=cog_instance, config_folder=cog_data_path(raw_name="PyLav"))
     cog_instance.bot = bot
     cog_instance.init_called = False
@@ -181,12 +260,15 @@ def class_factory(
     cog_instance.pylav = cog_instance.lavalink
     old_cog_on_command_error = cog_instance._get_overridden_method(cog_instance.cog_command_error)
     old_cog_unload = cog_instance._get_overridden_method(cog_instance.cog_unload)
+    old_cog_before_invoke = cog_instance._get_overridden_method(cog_instance.cog_before_invoke)
     old_cog_check = cog_instance._get_overridden_method(cog_instance.cog_check)
     old_cog_initialize = getattr(cog_instance, "initialize", None)
     if old_cog_on_command_error:
         cog_instance.__pylav_original_cog_command_error = old_cog_on_command_error
     if old_cog_unload:
         cog_instance.__pylav_original_cog_unload = old_cog_unload
+    if old_cog_before_invoke:
+        cog_instance.__pylav_original_cog_before_invoke = old_cog_before_invoke
     if old_cog_check:
         cog_instance.__pylav_original_cog_check = old_cog_check
     if old_cog_initialize:
@@ -194,6 +276,7 @@ def class_factory(
 
     cog_instance.cog_command_error = MethodType(cog_command_error, cog_instance)
     cog_instance.cog_unload = MethodType(cog_unload, cog_instance)
+    cog_instance.cog_before_invoke = MethodType(cog_before_invoke, cog_instance)
     cog_instance.initialize = MethodType(initialize, cog_instance)
     cog_instance.cog_check = MethodType(cog_check, cog_instance)
 
@@ -214,6 +297,8 @@ async def pylav_auto_setup(
     Adds `.lavalink` attribute to the cog instance and starts up PyLav
     Overwrites cog_unload method to unregister the cog from Lavalink,
         calling the original cog_unload method once the PyLav unregister code is run.
+    Overwrites cog_before_invoke
+        To force commands to wait for PyLav to be ready
     Overwrites cog_check method to check if the cog is allowed to run in the current context,
         If called within a Guild then we check if we can run as per the PyLav Command channel lock,
         if this check passes then the original cog_check method is called.
@@ -248,6 +333,10 @@ async def pylav_auto_setup(
         ...     await pylav_auto_setup(bot, MyCogClass, cogargs=(), cogkwargs=dict(special_arg=42), initargs=(), initkwargs=dict())
 
     """
+    if await asyncstdlib.any(bot.get_cog(name) is not None for name in INCOMPATIBLE_COGS if (_name := name)):
+        raise IncompatibleException(
+            f"{_name} is loaded, this cog is incompatible with PyLav - PyLav will not work as long as this cog is loaded."
+        )
     if cogargs is None:
         cogargs = ()
     if cogkwargs is None:
